@@ -39,7 +39,7 @@ extern "C" {
  *
  * ========== NOTE TO WINDOWS DEVELOPERS:
  * If you are compiling for Windows and will link to the static library
- * (libmikmod.a with MinGW, or mikmod_static.lib with MSVC or LCC, etc),
+ * (libmikmod.a with MinGW, or mikmod_static.lib with MSVC, Watcom, ..),
  * you must define MIKMOD_STATIC in your project.  Otherwise, dllimport
  * will be assumed.
  */
@@ -74,7 +74,7 @@ extern "C" {
 
 #define LIBMIKMOD_VERSION_MAJOR 3L
 #define LIBMIKMOD_VERSION_MINOR 3L
-#define LIBMIKMOD_REVISION     10L
+#define LIBMIKMOD_REVISION     13L
 
 #define LIBMIKMOD_VERSION \
     ((LIBMIKMOD_VERSION_MAJOR<<16)| \
@@ -87,7 +87,7 @@ MIKMODAPI extern long MikMod_GetVersion(void);
  *  ========== Dependency platform headers
  */
 
-#ifdef _WIN32
+#if defined(_WIN32)||defined(__CYGWIN__)
 #ifndef WIN32_LEAN_AND_MEAN
 #define WIN32_LEAN_AND_MEAN
 #endif
@@ -134,10 +134,8 @@ typedef unsigned char      UBYTE;
 #endif
 
 /* 2 bytes, signed and unsigned: */
-#ifndef __LCC__
 typedef signed short int   SWORD;
-#endif
-#if !(defined(__LCC__) || defined(_MIKMOD_AMIGA))
+#if !defined(_MIKMOD_AMIGA)
 typedef unsigned short int UWORD;
 #endif
 
@@ -252,14 +250,14 @@ enum {
     MMERR_MAC_SPEED,
     MMERR_MAC_START,
 
-    MMERR_OSX_UNKNOWN_DEVICE,
-    MMERR_OSX_BAD_PROPERTY,
+    MMERR_OSX_UNKNOWN_DEVICE, /* obsolete */
+    MMERR_OSX_BAD_PROPERTY,   /* obsolete */
     MMERR_OSX_UNSUPPORTED_FORMAT,
-    MMERR_OSX_SET_STEREO,
-    MMERR_OSX_BUFFER_ALLOC,
-    MMERR_OSX_ADD_IO_PROC,
+    MMERR_OSX_SET_STEREO,     /* obsolete */
+    MMERR_OSX_BUFFER_ALLOC,   /* obsolete */
+    MMERR_OSX_ADD_IO_PROC,    /* obsolete */
     MMERR_OSX_DEVICE_START,
-    MMERR_OSX_PTHREAD,
+    MMERR_OSX_PTHREAD,        /* obsolete */
 
     MMERR_DOSWSS_STARTDMA,
     MMERR_DOSSB_STARTDMA,
@@ -374,8 +372,9 @@ typedef struct MWRITER {
 #define SF_BIG_ENDIAN   0x0008
 #define SF_DELTA        0x0010
 #define SF_ITPACKED     0x0020
+#define SF_ADPCM4       0x0040
 
-#define SF_FORMATMASK   0x003F
+#define SF_FORMATMASK   0x007F
 
 /* General Playback flags */
 
@@ -549,6 +548,7 @@ struct MP_VOICE;
 #define UF_FT2QUIRKS    0x0200 /* emulate some FT2 replay quirks */
 #define UF_PANNING      0x0400 /* module uses panning effects or have
                                   non-tracker default initial panning */
+#define UF_FARTEMPO     0x0800 /* Module uses Farandole tempo calculations */
 
 typedef struct MODULE {
  /* general module information */
@@ -833,6 +833,7 @@ MIKMODAPI extern struct MDRIVER drv_osx;    /* MacOS X CoreAudio Driver */
 MIKMODAPI extern struct MDRIVER drv_dc;     /* Dreamcast driver */
 MIKMODAPI extern struct MDRIVER drv_gp32;   /* GP32 Sound driver */
 MIKMODAPI extern struct MDRIVER drv_psp;    /* PlayStation Portable driver */
+MIKMODAPI extern struct MDRIVER drv_n64;    /* Nintendo64 driver */
 
 MIKMODAPI extern struct MDRIVER drv_wss;    /* DOS WSS driver */
 MIKMODAPI extern struct MDRIVER drv_sb;     /* DOS S/B driver */
